@@ -4,8 +4,8 @@
 
 ;; Author: Karthik Chikmagalur <karthikchikmagalur@gmail.com>
 ;; Keywords: convenience, extensions
-;; Package-Version: 20250911.2339
-;; Package-Revision: 6d31046c5b18
+;; Package-Version: 20251210.758
+;; Package-Revision: a5e661de4d3c
 ;; Package-Requires: ((emacs "24.4"))
 ;; URL: https://github.com/karthink/timeout
 
@@ -86,7 +86,7 @@ This is intended for use as function advice."
         (result))
     (lambda (orig-fn &rest args)
       "Throttle calls to this function."
-      (prog1 result
+      (progn
         (unless (and throttle-timer (timerp throttle-timer))
           (setq result (apply orig-fn args))
           (setq throttle-timer
@@ -94,7 +94,8 @@ This is intended for use as function advice."
                  (timeout--eval-value timeout-value) nil
                  (lambda ()
                    (cancel-timer throttle-timer)
-                   (setq throttle-timer nil)))))))))
+                   (setq throttle-timer nil)))))
+        result))))
 
 (defun timeout--debounce-advice (&optional delay default)
   "Return a function that debounces its argument function.
@@ -188,7 +189,7 @@ previous successful call is returned."
             "\n\nThrottle calls to this function"))
           (interactive (advice-eval-interactive-spec
                         (cadr (interactive-form func))))
-          (prog1 result
+          (progn
             (unless (and throttle-timer (timerp throttle-timer))
               (setq result (apply func args))
               (setq throttle-timer
@@ -196,14 +197,15 @@ previous successful call is returned."
                      (timeout--eval-value throttle-value) nil
                      (lambda ()
                        (cancel-timer throttle-timer)
-                       (setq throttle-timer nil)))))))
+                       (setq throttle-timer nil)))))
+            result))
       ;; NON-INTERACTIVE version
       (lambda (&rest args)
         (:documentation
          (concat
           (documentation func)
           "\n\nThrottle calls to this function"))
-        (prog1 result
+        (progn
           (unless (and throttle-timer (timerp throttle-timer))
             (setq result (apply func args))
             (setq throttle-timer
@@ -211,7 +213,8 @@ previous successful call is returned."
                    (timeout--eval-value throttle-value) nil
                    (lambda ()
                      (cancel-timer throttle-timer)
-                     (setq throttle-timer nil))))))))))
+                     (setq throttle-timer nil)))))
+          result)))))
 
 (defun timeout-debounced-func (func &optional delay default)
   "Return a debounced version of function FUNC.
